## Installation of pyicon

### On Levante

Activate a suitable python environment. E.g.:
```
module load python3/2023.01-gcc-11.2.0
```
Other supported python environments are: `python3/2022.01-gcc-11.2.0(default)`,  `python3/2023.01-gcc-11.2.0`, and `python3/unstable`.

Download `pyicon` via git (preferably in your home directory, otherwise see `here`):
```
git clone https://gitlab.dkrz.de/m300602/pyicon.git
```

Install `pyicon` via:
```
cd pyicon
pip install -e .
``` 

### On an arbitrary system

pyicon is developed for python 3.8 or later. Other versions might work as well but are not supported so far.
Dependencies are listed in `pyicon/requirements.txt`, however, there are currently three python packages 
that cannot easily installed via pip.

Therefore, it is recommended to setup a mamba environment and install:
```
mamba create -n pyicon_311 -c conda-forge python=3.11 zarr cartopy dask 
mamba activate pyicon_311
```

Afterwards you can install pyicon with pip:
```
cd pyicon
pip install -e .
```

The above instructions will provide a minimum python environment that will be sufficient for most applications. 
However, some more advanced features might require the installation of further python packages.
For a complete list of python packages that is supposed to cover all aspects can be obtained from the latest 
`pyicon/ci/requirements*.yml` file. 

### From pypi

One might also install `pyicon` from pypi by
```
pip install pyicon-diagnostics
```

However, since `pyicon` is under frequent development and new features and bug fixes sometimes take some time 
to be put to pypi it is rather recommended to follow the above instructions with a local installation by 
`pip install -e .`.

### Update pyicon

If `pyicon` was downloaded via git and installed with `pip install -e .`, one can simply update `pyicon` by a
```
git pull
```
somewhere within the `pyicon` directory.

If `pyicon` was downloaded via pypi, you can update it with:
```
pip install pyicon-diagnostics --upgrade
```

### Verify the installation

You can check, if you can load `pyicon` by:
```
python -c "import pyicon"
```
Do not execute this command within a directory that is one directory below `pyicon`, 
e.g. if `pyicon` was installed in your home, thus under `~/pyicon`, do not execute this command 
in your home directory.

If there are issues with loading `pyicon`, you might want to set a python path either, in your shell:
``` 
export PYTHONPATH="${HOME}/pyicon:${PYTHONPATH}"
```

Alternatively, you can also expand the python pass on top of your python script 
or notebook, by adding:
```
import sys, os
sys.path.append(f"{os.path.expanduser('~')}/pyicon")
import pyicon as pyic
```